# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'C:\Users\Yuki\Dropbox\python\my_module_root\kuchinawa\kuchinawa\Exapmles\SinCos.ui'
#
# Created by: PyQt5 UI code generator 5.6
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(928, 669)
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setGeometry(QtCore.QRect(10, 200, 451, 301))
        self.groupBox.setObjectName("groupBox")
        self.lcdNumber_sin = QtWidgets.QLCDNumber(self.groupBox)
        self.lcdNumber_sin.setGeometry(QtCore.QRect(40, 60, 191, 61))
        self.lcdNumber_sin.setObjectName("lcdNumber_sin")
        self.dial_sin = QtWidgets.QDial(self.groupBox)
        self.dial_sin.setGeometry(QtCore.QRect(40, 130, 191, 171))
        self.dial_sin.setObjectName("dial_sin")
        self.amp_sin = QtWidgets.QSlider(self.groupBox)
        self.amp_sin.setGeometry(QtCore.QRect(290, 80, 22, 160))
        self.amp_sin.setProperty("value", 50)
        self.amp_sin.setOrientation(QtCore.Qt.Vertical)
        self.amp_sin.setObjectName("amp_sin")
        self.noise_sin = QtWidgets.QSlider(self.groupBox)
        self.noise_sin.setGeometry(QtCore.QRect(370, 80, 22, 160))
        self.noise_sin.setOrientation(QtCore.Qt.Vertical)
        self.noise_sin.setObjectName("noise_sin")
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setGeometry(QtCore.QRect(260, 40, 62, 15))
        self.label.setObjectName("label")
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setGeometry(QtCore.QRect(350, 40, 62, 15))
        self.label_2.setObjectName("label_2")
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setGeometry(QtCore.QRect(40, 30, 62, 15))
        self.label_5.setObjectName("label_5")
        self.label_6 = QtWidgets.QLabel(self.groupBox)
        self.label_6.setGeometry(QtCore.QRect(40, 140, 62, 15))
        self.label_6.setObjectName("label_6")
        self.groupBox_3 = QtWidgets.QGroupBox(Form)
        self.groupBox_3.setGeometry(QtCore.QRect(470, 200, 451, 301))
        self.groupBox_3.setObjectName("groupBox_3")
        self.lcdNumber_cos = QtWidgets.QLCDNumber(self.groupBox_3)
        self.lcdNumber_cos.setGeometry(QtCore.QRect(40, 60, 191, 61))
        self.lcdNumber_cos.setObjectName("lcdNumber_cos")
        self.dial_cos = QtWidgets.QDial(self.groupBox_3)
        self.dial_cos.setGeometry(QtCore.QRect(40, 130, 191, 171))
        self.dial_cos.setObjectName("dial_cos")
        self.amp_cos = QtWidgets.QSlider(self.groupBox_3)
        self.amp_cos.setGeometry(QtCore.QRect(290, 80, 22, 160))
        self.amp_cos.setProperty("value", 50)
        self.amp_cos.setOrientation(QtCore.Qt.Vertical)
        self.amp_cos.setObjectName("amp_cos")
        self.noise_cos = QtWidgets.QSlider(self.groupBox_3)
        self.noise_cos.setGeometry(QtCore.QRect(370, 80, 22, 160))
        self.noise_cos.setOrientation(QtCore.Qt.Vertical)
        self.noise_cos.setObjectName("noise_cos")
        self.label_13 = QtWidgets.QLabel(self.groupBox_3)
        self.label_13.setGeometry(QtCore.QRect(260, 40, 62, 15))
        self.label_13.setObjectName("label_13")
        self.label_14 = QtWidgets.QLabel(self.groupBox_3)
        self.label_14.setGeometry(QtCore.QRect(350, 40, 62, 15))
        self.label_14.setObjectName("label_14")
        self.label_15 = QtWidgets.QLabel(self.groupBox_3)
        self.label_15.setGeometry(QtCore.QRect(40, 30, 62, 15))
        self.label_15.setObjectName("label_15")
        self.label_16 = QtWidgets.QLabel(self.groupBox_3)
        self.label_16.setGeometry(QtCore.QRect(40, 140, 62, 15))
        self.label_16.setObjectName("label_16")
        self.lineEdit = QtWidgets.QLineEdit(Form)
        self.lineEdit.setGeometry(QtCore.QRect(90, 90, 581, 21))
        self.lineEdit.setObjectName("lineEdit")
        self.label_3 = QtWidgets.QLabel(Form)
        self.label_3.setGeometry(QtCore.QRect(80, 40, 171, 31))
        self.label_3.setStyleSheet("font: 12pt \"MS UI Gothic\";")
        self.label_3.setObjectName("label_3")

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.groupBox.setTitle(_translate("Form", "Sin"))
        self.label.setText(_translate("Form", "Amp"))
        self.label_2.setText(_translate("Form", "Noise"))
        self.label_5.setText(_translate("Form", "Current"))
        self.label_6.setText(_translate("Form", "Phase"))
        self.groupBox_3.setTitle(_translate("Form", "Cos"))
        self.label_13.setText(_translate("Form", "Amp"))
        self.label_14.setText(_translate("Form", "Noise"))
        self.label_15.setText(_translate("Form", "Current"))
        self.label_16.setText(_translate("Form", "Phase"))
        self.label_3.setText(_translate("Form", "Output file path: "))

